package cn.wustlinghang.wusthelper.internal.undergrad.api.json;

import cn.wustlinghang.mywust.core.parser.undergraduate.UndergradStudentInfoPageParser;
import cn.wustlinghang.mywust.core.request.service.undergraduate.UndergradStudentInfoApiService;
import cn.wustlinghang.mywust.data.global.StudentInfo;
import cn.wustlinghang.mywust.exception.ApiException;
import cn.wustlinghang.mywust.exception.ParseException;
import cn.wustlinghang.wusthelper.rpc.response.RpcResponse;
import jakarta.enterprise.context.ApplicationScoped;
import jakarta.validation.constraints.NotNull;
import jakarta.ws.rs.GET;
import jakarta.ws.rs.POST;
import jakarta.ws.rs.Path;
import jakarta.ws.rs.QueryParam;

import java.io.IOException;

@Path("/training_plan")
@ApplicationScoped
public class TrainingPlanApi {
    private final UndergradStudentInfoApiService studentInfoApiService;
    private final UndergradStudentInfoPageParser studentInfoPageParser;

    public TrainingPlanApi(UndergradStudentInfoApiService studentInfoApiService,
                           UndergradStudentInfoPageParser studentInfoPageParser) {
        this.studentInfoApiService = studentInfoApiService;
        this.studentInfoPageParser = studentInfoPageParser;
    }

    @GET
    @Path("/")
    public RpcResponse<StudentInfo> get(String cookie) throws IOException, ApiException, ParseException {
        String html =  studentInfoApiService.getPage(cookie);
        return this.parse(html);
    }

    @GET
    @Path("/agent")
    public RpcResponse<String> agent(@QueryParam("cookie") @NotNull String cookie)
            throws IOException, ApiException {
        String html =  studentInfoApiService.getPage(cookie);
        return RpcResponse.success(html);
    }

    @POST
    @Path("/parse")
    public RpcResponse<StudentInfo> parse(String html) throws ParseException {
        StudentInfo result = studentInfoPageParser.parse(html);
        return RpcResponse.success(result);
    }
}
